@@ -89,6 +89,14 @@ extern void rb_marshal_VOID__POINTER_INT_POINTER_POINTER (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
+/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:12) */
+extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __rb_marshal_MARSHAL_H__ */
